const Me = imports.misc.extensionUtils.getCurrentExtension();
const ScrollMenu = Me.imports.scrollMenu;
const MenuItem = Me.imports.menuItem;
const Settings = Me.imports.settings;
const ConfirmDialog = Me.imports.confirmDialog;
const log = Me.imports.log;
var TrashMenu = class TrashMenu extends ScrollMenu.ScrollMenu {
    constructor(settings, doOpenItem, doDeleteItem, doRestoreItem) {
        super();
        this._settings = settings;
        this._doOpenItem = doOpenItem;
        this._doDeleteItem = doDeleteItem;
        this._doRestoreItem = doRestoreItem;
    }
    rebuildMenu(trash) {
        log.info(`rebuild menu`);
        super.removeAll();
        trash.forEach((info, _) => {
            let item = new MenuItem.MenuItem(info, this._onActivateItem.bind(this), this._onDeleteItem.bind(this), this._onRestoreItem.bind(this));
            super.addMenuItem(item);
        });
    }
    _onActivateItem(item) {
        switch (this._settings.activation()) {
            case Settings.ACTIVATION_OPEN:
                this._doOpenItem(item);
                break;
            case Settings.ACTIVATION_DELETE:
                this._onDeleteItem(item);
                break;
            case Settings.ACTIVATION_RESTORE:
                this._onRestoreItem(item);
                break;
            default:
                log.error(`invalid activation ${this._settings.activation()}`);
        }
    }
    _onDeleteItem(item) {
        let title = _("Delete item permanently");
        let message = _(`Are you sure you want to delete '${item.filename}'?`);
        let subMessage = _("This operation cannot be undone.");
        ConfirmDialog.openConfirmDialog(title, message, subMessage, this._doDeleteItem(item), _("Delete"));
    }
    _onRestoreItem(item) {
        let title = _("Restore item?");
        let message = _(`Restore '${item.filename}' to: '${item.restorePath}'`);
        let sub_message = _(`Deleted at: ${item.deletedAt}`);
        ConfirmDialog.openConfirmDialog(title, message, sub_message, this._doRestoreItem(item), _("Restore"));
    }
}
